@@ -168,8 +168,8 @@ def get_all_pairs_of_residues_in_motif_MST(motif_MST: nx.Graph) -> Dict[Tuple[st
     that of a Depth First Search (dfs). If the residue pairs were randomly ordered, we wouldn't be able to do the connectivity check 
     in update_map_of_PDBs_with_all_residue_pairs, because the logic requires that new residue pairs are connected to already visited nodes.
     """
-    MST_edges: List[Tuple[str, str]] = list(nx.dfs_edges(motif_MST)) # Ex: [('A1G', 'A3K'), ('A3K', 'A8N'), ...]
-    
+    MST_edges: List[Tuple[str, str]] = list(nx.edge_dfs(motif_MST)) # Ex: [('A1G', 'A3K'), ('A3K', 'A8N'), ...]
+
     all_pairs_of_residues_in_motif_MST: Dict[Tuple[str,str], Residue_pair_data] = {}
     for pair_of_full_residue_IDs in MST_edges:
         pair_of_full_residue_IDs = get_sorted_2_tuple(pair_of_full_residue_IDs) # Ordering is needed to make sure we only calculate each pair once, i.e avoid calculating the results of (A,B) and (B,A), as they are identical.
@@ -427,7 +427,6 @@ def filter_out_PDBs_with_unconnected_residue_pairs(
 
         PDB_ID = submited_futures[future]
         monomorphism_checked_motifs = future.result()
-        
         if not monomorphism_checked_motifs: # These are the false positive PDBs, i.e PDBs that have all the residue pairs but where the monomorphism check doesn't find any similar motif as a result of unconnected pairs of residues 
             continue
 
@@ -471,7 +470,7 @@ def solve_motif_MST(
         PDB_ID, pairs_of_residues = map_of_PDBs_with_all_residue_pairs.popitem()
         monomorphism_checked_motifs = run_subgraph_monomorphism(motif_MST, pairs_of_residues)
         
-        if not monomorphism_checked_motifs: # These are the false positive PDBs, i.e PDBs that have all the residue pairs but where the monomorphism check doesn't find any similar motif as a result of unconnected pairs of residues 
+        if not monomorphism_checked_motifs: # These are the false positive PDBs, i.e PDBs that have all the residue pairs but where the monomorphism check doesn't find any similar motif
             continue
 
         filtered_PDBs_with_all_residue_pairs[PDB_ID] = monomorphism_checked_motifs
@@ -495,9 +494,7 @@ def get_PDBs_with_similar_motifs(
         if n_motifs_to_solve <= n_cores:
             for motif_MST in get_all_motif_MSTs_generator(reference_motif_MST, max_n_mutated_residues, residue_type_policy, motif_residues_data):
                 PDBs_with_all_residue_pairs = find_PDBs_with_all_residue_pairs(motif_MST, index_folder_path, distance_delta_thr, angle_delta_thr, compression, concurrent_executor)
-                print(len(PDBs_with_all_residue_pairs))
                 filtered_PDBs_with_all_residue_pairs = filter_out_PDBs_with_unconnected_residue_pairs(PDBs_with_all_residue_pairs, motif_MST, concurrent_executor)
-                print(len(filtered_PDBs_with_all_residue_pairs))
 
                 if filtered_PDBs_with_all_residue_pairs:
                     motif_MST_filtered_PDBs_map[motif_MST] = filtered_PDBs_with_all_residue_pairs
@@ -521,7 +518,7 @@ def get_PDBs_with_similar_motifs(
                     motif_MST_filtered_PDBs_map[motif_MST] = filtered_PDBs_with_all_residue_pairs
 
                 tqdm_progress_bar.update()
-    
+
     return motif_MST_filtered_PDBs_map
 
 def search_index_for_PDBs_with_similar_motifs(
